@@ -127,11 +127,11 @@ class Text(Transform):
         result = []
         for group in groups:
             result.extend(self._items[group])
-        result = list(set(result))
+        result = list(sorted(set(result)))
         return result
 
     def groups(self, *args):
-        return Items(self.context, self._groups(args))
+        return Items(self.context, self._groups(*args))
 
     def _groups_from_items(self):
         return frozenset(self._items.keys())
